@@ -1,4 +1,4 @@
-#include "squid-old.h"
+#include "squid.h"
 #include "MmappedDiskIOModule.h"
 #include "MmappedIOStrategy.h"
 
@@ -18,10 +18,9 @@ MmappedDiskIOModule::init()
 {}
 
 void
-MmappedDiskIOModule::shutdown()
+MmappedDiskIOModule::gracefulShutdown()
 {}
 
-
 DiskIOStrategy*
 MmappedDiskIOModule::createStrategy()
 {
